======================
微信支付
======================

:Author: SivaCoHan <sivacohan@gmail.com>
:Date: 2015-05-19

.. contents:: Index
.. sectnum::

说明
----------

根据当前的微信支付文档. 提供了对微信支付的封装.

暂时支持两种扫码支付方式, 提供一种JSAPI支持.


Version
--------

0.13 Add openid support by: <https://github.com/aetherwu>
